==> react-image-annotate-fork-1.0.12.tgz: package/SettingsProvider/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { createContext, useContext, useState } from "react";
var defaultSettings = {
  showCrosshairs: false,
  showHighlightBox: true,
  wasdMode: true
};
export var SettingsContext = createContext(defaultSettings);

var pullSettingsFromLocalStorage = function pullSettingsFromLocalStorage() {
  if (!window || !window.localStorage) return {};
  var settings = {};

  for (var i = 0; i < window.localStorage.length; i++) {
    var key = window.localStorage.key(i);

    if (key.startsWith("settings_")) {
      try {
        settings[key.replace("settings_", "")] = JSON.parse(window.localStorage.getItem(key));
      } catch (e) {}
    }
  }

  return settings;
};

export var useSettings = function useSettings() {
  return useContext(SettingsContext);
};
export var SettingsProvider = function SettingsProvider(_ref) {
  var _ref$showCrosshairs = _ref.showCrosshairs,
      showCrosshairs = _ref$showCrosshairs === void 0 ? false : _ref$showCrosshairs,
      children = _ref.children;

  var _useState = useState(_objectSpread({}, defaultSettings, {
    showCrosshairs: showCrosshairs
  })),
      _useState2 = _slicedToArray(_useState, 2),
      state = _useState2[0],
      changeState = _useState2[1];

  var changeSetting = function changeSetting(setting, value) {
    changeState(_objectSpread({}, state, _defineProperty({}, setting, value)));
    window.localStorage.setItem("settings_".concat(setting), JSON.stringify(value));
  };

  return React.createElement(SettingsContext.Provider, {
    value: _objectSpread({}, state, {
      changeSetting: changeSetting
    })
  }, children);
};
export default SettingsProvider;

==> react-image-annotate-fork-1.0.16.tgz: package/SettingsProvider/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { createContext, useContext, useState } from "react";
var defaultSettings = {
  showCrosshairs: false,
  showHighlightBox: true,
  wasdMode: true
};
export var SettingsContext = createContext(defaultSettings);

var pullSettingsFromLocalStorage = function pullSettingsFromLocalStorage() {
  if (!window || !window.localStorage) return {};
  var settings = {};

  for (var i = 0; i < window.localStorage.length; i++) {
    var key = window.localStorage.key(i);

    if (key.startsWith("settings_")) {
      try {
        settings[key.replace("settings_", "")] = JSON.parse(window.localStorage.getItem(key));
      } catch (e) {}
    }
  }

  return settings;
};

export var useSettings = function useSettings() {
  return useContext(SettingsContext);
};
export var SettingsProvider = function SettingsProvider(_ref) {
  var showCrosshairs = _ref.showCrosshairs,
      children = _ref.children;

  var _useState = useState(_objectSpread({}, defaultSettings, {
    showCrosshairs: showCrosshairs
  })),
      _useState2 = _slicedToArray(_useState, 2),
      state = _useState2[0],
      changeState = _useState2[1];

  var changeSetting = function changeSetting(setting, value) {
    changeState(_objectSpread({}, state, _defineProperty({}, setting, value)));
    window.localStorage.setItem("settings_".concat(setting), JSON.stringify(value));
  };

  return React.createElement(SettingsContext.Provider, {
    value: _objectSpread({}, state, {
      changeSetting: changeSetting
    })
  }, children);
};
export default SettingsProvider;
